"""
Licensed to the Apache Software Foundation (ASF) under one
or more contributor license agreements.  See the NOTICE file
distributed with this work for additional information
regarding copyright ownership.  The ASF licenses this file
to you under the Apache License, Version 2.0 (the
"License"); you may not use this file except in compliance
with the License.  You may obtain a copy of the License at

  http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing,
software distributed under the License is distributed on an
"AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
KIND, either express or implied.  See the License for the
specific language governing permissions and limitations
under the License.
"""
# -*- coding: utf-8 -*-
import citrusleaf as cl

def create_index(ip, port, namespace, index_name, bin_name, bin_type, set_name=None, sock=None):

    if set_name is not None:
        arg = "sindex-create:ns="+ str(namespace) +";set=" +  str(set_name) + ";indexname="+ str(index_name) +";numbins=1;indexdata="+str(bin_name)+","+str(bin_type)+";priority=normal"
    else:
        arg = "sindex-create:ns="+ str(namespace) +";indexname="+str(index_name)+";numbins=1;indexdata="+str(bin_name)+","+str(bin_type)+";priority=normal"
    response = cl.citrusleaf_info(ip, port, arg, sock=sock)
    if response == "OK":
        return dict(status="success")
    first_occurence = str(response).find(':')
    second_occurence = str(response).find(':', first_occurence+1)
    resp = str(response)[second_occurence+1:]
    return dict(status="failure", error=str(resp))


def drop_index(ip, port, namespace, index_name, sock=None):

    arg = "sindex-delete:ns=" + str(namespace) + ";indexname=" + str(index_name)
    response = cl.citrusleaf_info(ip, port, arg, sock=sock)
    if response == "OK":
        return dict(status="success")
    first_occurence = str(response).find(':')
    second_occurence = str(response).find(':', first_occurence+1)
    resp = str(response)[second_occurence+1:]
    return dict(status="failure", error=str(resp))


def add_udf(ip, port, file_name, file_contents, content_length, udf_type, sock=None):

    arg = "udf-put:filename="+str(file_name)+";content="+str(file_contents)+";content-len="+str(content_length)+";udf-type="+ str(udf_type)
    response = cl.citrusleaf_info(ip, port, arg, sock=sock)
    if response == '':
        return dict(status="success")
    start = str(response).find('error')
    end = str(response).find(';', start)
    error = str(response)[start:end]
    if 'compile_error' not in error:
        start = str(response).find('message')
        end = str(response).find(';', start)
        resp = str(response)[:start]
        if end is not -1:
            resp = resp + str(response)[end + 1:]
        response = str(resp)
    return dict(status="failure", error=str(response))


def drop_udf(ip, port, file_name, sock=None):

    arg = "udf-remove:filename="+str(file_name) + ";"
    response = cl.citrusleaf_info(ip, port, arg, sock=sock)
    if response == 'ok':
        return dict(status="success")
    start = str(response).find('message')
    end = str(response).find(';', start)
    resp = str(response)[:start]
    if end is not -1:
        resp = resp + str(response)[end + 1:]
    response = str(resp)
    return dict(status="failure", error=str(response))